Macro proc_easy::easy_argument_tuple
source · [−]macro_rules! easy_argument_tuple {
(
$(#[$meta:meta])*
$vis:vis struct $name:ident {
$(#[$nmeta:meta])* $nvis:vis $nname:ident: $ntype:ty
$(, $(#[$fmeta:meta])* $fvis:vis $fname:ident: $ftype:ty)*
$(,)?
}
) => { ... };
}Expand description
Defines argument structure.
First field is a argument name.
It must be EasyToken implementation that will be used to for EasyPeek implementation.
Following fields must be EasyArgumentField and are expected to be in parenthesized and parsed in any order.
If name is not followed by parentheses, all fields are missing.
In case of errors, argument name and span will be used.