pub trait EasyArgument: EasyPeek {
// Required methods
fn name_display() -> &'static str;
fn name_span(&self) -> Span;
}Expand description
Trait for parsable arguments. Arguments have a token as a name that is used for peeking. Name of the argument can be displayed for user in some error cases.
Required Methods
Sourcefn name_display() -> &'static str
fn name_display() -> &'static str
Returns attribute name for display purposes.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".