pub trait EasyAttributes {
// Required methods
fn parse(attrs: &[Attribute], span: Span) -> Result<Self>
where Self: Sized;
fn parse_in(
namespace: &Ident,
attrs: &[Attribute],
span: Span,
) -> Result<Self>
where Self: Sized;
}Expand description
Collection of attributes that can be parsed from array of attributes.
Can be easily applied to attributes vector parsed by syn.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".